@@ -20,6 +20,7 @@ from abc import abstractmethod
 from random import choice
 from random import randint
 
+from nise.generators.aws.aws_constants import REGIONS
 from nise.generators.generator import AbstractGenerator
 
 
@@ -203,50 +204,6 @@ class AWSGenerator(AbstractGenerator):
         + SAVINGS_COLS
         + tuple(RESOURCE_TAG_COLS)
     )
-    REGIONS = (
-        ("US East (N. Virginia)", "us-east-1", "us-east-1a", "USE1-EBS"),
-        ("US East (N. Virginia)", "us-east-1", "us-east-1b", "USE1-EBS"),
-        ("US East (N. Virginia)", "us-east-1", "us-east-1c", "USE1-EBS"),
-        ("US East (N. Virginia)", "us-east-1", "us-east-1d", "USE1-EBS"),
-        ("US East (N. Virginia)", "us-east-1", "us-east-1e", "USE1-EBS"),
-        ("US East (N. Virginia)", "us-east-1", "us-east-1f", "USE1-EBS"),
-        ("US West (N. California)", "us-west-1", "us-west-1a", "USW1-EBS"),
-        ("US West (N. California)", "us-west-1", "us-west-1b", "USW1-EBS"),
-        ("US West (Oregon)", "us-west-2", "us-west-2a", "USW2-EBS"),
-        ("US West (Oregon)", "us-west-2", "us-west-2b", "USW2-EBS"),
-        ("US West (Oregon)", "us-west-2", "us-west-2c", "USW2-EBS"),
-        ("Europe (Stockholm)", "eu-north-1", "eu-north-1a", "EUN1-EBS"),
-        ("Europe (Ireland)", "eu-west-1", "eu-west-1a", "EUW1-EBS"),
-        ("Europe (Ireland)", "eu-west-1", "eu-west-1b", "EUW1-EBS"),
-        ("Europe (Ireland)", "eu-west-1", "eu-west-1c", "EUW1-EBS"),
-        ("Europe (Frankfurt)", "eu-central-1", "eu-central-1a", "EUC1-EBS"),
-        ("Europe (Frankfurt)", "eu-central-1", "eu-central-1b", "EUC1-EBS"),
-        ("Europe (London)", "eu-west-2", "eu-west-2a", "EUW2_EBS"),
-        ("Europe (Paris)", "eu-west-3", "eu-west-3a", "EUW3_EBS"),
-        ("Europe (Milan)", "eu-south-1", "eu-south-1", "EUN1-EBS"),
-        ("Middle East (Bahrain)", "me-south-1", "me-south-1a", "MES1-EBS"),
-        ("Asia Pacific (Hong Kong)", "ap-east-1", "ap-east-1a", "APE1-EBS"),
-        ("Asia Pacific (Singapore)", "ap-southeast-1", "ap-southeast-1a", "APSE1-EBS"),
-        ("Asia Pacific (Singapore)", "ap-southeast-1", "ap-southeast-1b", "APSE1-EBS"),
-        ("Asia Pacific (Sydney)", "ap-southeast-2", "ap-southeast-2a", "APSE2-EBS"),
-        ("Asia Pacific (Sydney)", "ap-southeast-2", "ap-southeast-2b", "APSE2-EBS"),
-        ("Asia Pacific (Sydney)", "ap-southeast-2", "ap-southeast-2c", "APSE2-EBS"),
-        ("Asia Pacific (Tokyo)", "ap-northeast-1", "ap-northeast-1a", "APNE1-EBS"),
-        ("Asia Pacific (Tokyo)", "ap-northeast-1", "ap-northeast-1c", "APNE1-EBS"),
-        ("Asia Pacific (Seoul)", "ap-northeast-2", "ap-northeast-2a", "APNE2-EBS"),
-        ("Asia Pacific (Osaka-Local)", "ap-northeast-3", "ap-northeast-3a", "APNE3-EBS"),
-        ("China (Beijing)", "cn-north-1", "cn-north-1a", "CNN1-EBS"),
-        ("China (Ningxia)", "cn-northwest-1", "cn-northwest-1a", "CNNW1-EBS"),
-        ("SA East (Sao Paulo)", "sa-east-1", "sa-east-1a", "SA1-EBS"),
-        ("SA East (Sao Paulo)", "sa-east-1", "sa-east-1b", "SA1-EBS"),
-        ("SA East (Sao Paulo)", "sa-east-1", "sa-east-1c", "SA1-EBS"),
-        ("Asia Pacific (Mumbai)	", "ap-south-1", "ap-south-1a", "APS1-EBS"),
-        ("Asia Pacific (Mumbai)	", "ap-south-1", "ap-south-1b", "APS1-EBS"),
-        ("Canada (Central)", "ca-central-1", "ca-central-1a", "CAC1-EBS"),
-        ("Africa (Cape Town)", "af-south-1", "af-south-1a", "AFS1-EBS"),
-        ("AWS GovCloud (US-East)", "us-gov-east-1", "us-gov-east-1a", "USGE1-EBS"),
-        ("AWS GovCloud (US)", "us-gov-west-1", "us-gov-west-1a", "USGW1-EBS"),
-    )
 
     def __init__(self, start_date, end_date, payer_account, usage_accounts, attributes=None, tag_cols=None):
         """Initialize the generator."""
@@ -317,11 +274,11 @@ class AWSGenerator(AbstractGenerator):
         options = None
         if self.attributes and self.attributes.get("region"):
             region = self.attributes.get("region")
-            options = [option for option in self.REGIONS if region in option]
+            options = [option for option in REGIONS if region in option]
         if options:
             location = choice(options)
         else:
-            location = choice(self.REGIONS)
+            location = choice(REGIONS)
         return location
 
     def _add_common_usage_info(self, row, start, end, **kwargs):
